#!/bin/bash
# Find executor jar and start springboot process

export JFI_HOME="/opt/jfrog"
export JFEX_APP_NAME=${JFEX_APP_NAME:-insight-executor}
export JFI_HOME_EXECUTOR="${JFI_HOME}/${JFEX_APP_NAME}"
export JFMC_LOGS=${JFMC_LOGS:-${JFI_HOME_EXECUTOR}/logs}
EXECUTOR_PORT=8080

logger() {
    DATE_TIME=$(date +"%Y-%m-%d %H:%M:%S")
    if [ -z "$CONTEXT" ]
    then
        CONTEXT=$(caller)
    fi
    MESSAGE=$1
    CONTEXT_LINE=$(echo "$CONTEXT" | awk '{print $1}')
    CONTEXT_FILE=$(echo "$CONTEXT" | awk -F"/" '{print $NF}')
    printf "%s %05s %s %s\n" "$DATE_TIME" "[$CONTEXT_LINE" "$CONTEXT_FILE]" "$MESSAGE"
    CONTEXT=
}

errorExit () {
    echo; logger "ERROR: $1"; echo
    exit 1
}

warn () {
    logger "WARNING: $1"
}

# Test directory has read/write permissions for current user
testDirectoryPermissions () {
    local dir_to_check=$1
    local error=false
    local error_type=

    [ -d ${dir_to_check} ] || errorExit "'${dir_to_check}' is not a directory"

    logger "Testing directory (${dir_to_check}) has read/write permissions"

    local test_file=${dir_to_check}/test-permissions

    # Write file
    if echo test > ${test_file} 1> /dev/null 2>&1; then
        # Write succeeded. Testing read...
        if cat ${test_file} > /dev/null; then
            logger "${dir_to_check} has read/write permissions for ${JFMC_USER_NAME}"
            rm -f ${test_file}
        else
            error=true
            error_type=readable
        fi
    else
        error=true
        error_type=writable
    fi

    if [ "${error}" == true ]; then
        local stat_data=$(stat -Lc "Directory: %n, permissions: %a, owner: %U, group: %G" ${dir_to_check})
        logger "###########################################################"
        logger "${dir_to_check} is NOT ${error_type}!"
        logger "${stat_data}"
        logger "Mounted directory must be ${error_type} by user '${JFMC_USER_NAME}' (id ${JFMC_USER_ID})"
        logger "###########################################################"
        errorExit "Directory ${dir_to_check} has bad permissions for user '${JFMC_USER_NAME}'"
    fi
}

# Test permissions on JFMC_LOGS
testPermissions () {
    # JFMC_LOGS folder
    testDirectoryPermissions ${JFMC_LOGS}
}

testPermissions

EXECUTOR_JAR=`find /executor -name "*.jar" | head -1`
[[ -f "$EXECUTOR_JAR" ]] || errorExit "Could not find (or access) application jar under /executor in the container"

exec java -Dserver.port=${EXECUTOR_PORT} -XX:+UseG1GC $JFMC_EXTRA_JAVA_OPTS -jar "$EXECUTOR_JAR"